window.addEventListener( 'DOMContentLoaded', function() {
  if ( failed == true ) {
    $('loginError').removeClass( 'hidden' );
  }
} );
